<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/core/ui/about.cpp" line="40"/>
        <source>About</source>
        <translation>정보</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="41"/>
        <source>Thanks</source>
        <translation>도움을 주신 분들</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="42"/>
        <source>Help us</source>
        <translation>도와주세요</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="99"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>은 데스크톱의 스크린숏을 빠르게 생성할 수 있는 크로스 플랫폼 애플리케이션입니다.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="101"/>
        <source>It is a light and powerful application, written in Qt.</source>
        <translation>Qt로 작성된 가볍고 강력한 응용 프로그램입니다.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="33"/>
        <source>using Qt %1</source>
        <translation>Qt %1 사용 중</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="104"/>
        <source>Website - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</source>
        <translation>웹사이트 - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="107"/>
        <source>Licensed under the &lt;a href=%1&gt;GPL v2&lt;/a&gt;</source>
        <translation>&lt;a href=%1&gt;GPL v2&lt;/a&gt;에 따라 라이선스 부여됨</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="111"/>
        <source>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</source>
        <translation>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="113"/>
        <source>Copyright &amp;copy; 2013-2025, LXQt team</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="120"/>
        <source>You can join us and help us if you want. This is an invitation if you like this application.</source>
        <translation>당신이 원한다면 우리와 합류해서 우리를 도울 수 있습니다. 당신이 이 응용 프로그램을 좋아한다면 이것은 초대장입니다.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="123"/>
        <source>What you can do?</source>
        <translation>당신은 무엇을 할 수 있습니까?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="126"/>
        <source>Translate ScreenGrab to other languages</source>
        <translation>ScreenGrab을 다른 언어로 번역</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="127"/>
        <source>Make suggestions for next releases</source>
        <translation>다음 릴리스에 대한 제안</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="128"/>
        <source>Report bugs and issues</source>
        <translation>버그 및 문제 보고</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="131"/>
        <source>Bug tracker</source>
        <translation>버그 추적기</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="142"/>
        <source>Special thanks to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="144"/>
        <source>for creating ScreenGrab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="145"/>
        <source>for supporting wlr screencopy protocol</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="190"/>
        <source>Directory %1 does not exist. Do you want to create it?</source>
        <translation>%1 디렉터리가 없습니다. 만드시겠습니까?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="191"/>
        <location filename="../src/core/ui/configwidget.cpp" line="280"/>
        <source>Warning</source>
        <translation>경고</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="268"/>
        <source>Select directory</source>
        <translation>디렉터리 선택</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="279"/>
        <source>Do you want to reset the settings to the defaults?</source>
        <translation>설정을 기본값으로 재설정하시겠습니까?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="313"/>
        <source>Example: </source>
        <translation>예시: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="354"/>
        <source>This key is already used in ScreenGrab! Please select another.</source>
        <translation>이 키는 이미 ScreenGrab에서 사용 중입니다! 다른 키를 선택해 주세요.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="372"/>
        <source>This key is not supported on your system!</source>
        <translation>이 키는 시스템에서 지원되지 않습니다!</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="392"/>
        <source>Error</source>
        <translation>오류</translation>
    </message>
</context>
<context>
    <name>Core</name>
    <message>
        <location filename="../src/core/core.cpp" line="66"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>은 데스크톱의 스크린숏을 빠르게 생성할 수 있는 크로스 플랫폼 애플리케이션입니다.</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="70"/>
        <source>Take a fullscreen screenshot</source>
        <translation>전체화면 스크린숏 찍기</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="74"/>
        <source>Take a screenshot of the active window</source>
        <translation>활성 창 스크린숏 찍기</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="78"/>
        <source>Take a screenshot of a selection of the screen</source>
        <translation>선택한 화면 스크린숏 찍기</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="82"/>
        <source>Run the application with a hidden main window</source>
        <translation>숨겨진 기본 창으로 응용 프로그램 실행</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="85"/>
        <source>Save screenshot and exit, without showing window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="575"/>
        <source>Saved</source>
        <translation>저장됨</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="575"/>
        <source>Saved to </source>
        <translation>저장 위치 </translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="597"/>
        <source>Name of saved file is copied to the clipboard</source>
        <translation>저장된 파일의 이름이 클립보드에 복사됩니다</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="603"/>
        <source>Path to saved file is copied to the clipboard</source>
        <translation>저장된 파일의 경로가 클립보드에 복사됩니다</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="626"/>
        <source>Copied</source>
        <translation>복사됨</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="626"/>
        <source>Screenshot is copied to clipboard</source>
        <translation>스크린숏이 클립보드에 복사되었습니다</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="14"/>
        <source>ScreenGrab</source>
        <translation>ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="73"/>
        <source>Screen:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="105"/>
        <source>Type:</source>
        <translation>유형:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="115"/>
        <source>Type of screenshot</source>
        <translation>스크린숏 유형</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="122"/>
        <source>Full screen</source>
        <translation>전체 화면</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="127"/>
        <source>Window</source>
        <translation>창</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="132"/>
        <source>Screen area</source>
        <translation>화면 영역</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="137"/>
        <source>Last selected area</source>
        <translation>마지막으로 선택한 영역</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="167"/>
        <source>Delay:</source>
        <translation>지연시간:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="180"/>
        <source>Delay in seconds before taking screenshot</source>
        <translation>스크린숏 찍기 전 지연 시간(초)</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="183"/>
        <source>None</source>
        <translation>없음</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="186"/>
        <source> sec</source>
        <translation> 초</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="245"/>
        <source>Zoom area around mouse</source>
        <translation>마우스 주변 영역 확대/축소</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="252"/>
        <source>No window decoration</source>
        <translation>창 장식 없음</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="259"/>
        <source>Include mouse pointer</source>
        <translation>마우스 포인터 포함</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="291"/>
        <source>toolBar</source>
        <translation>도구 모음</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="44"/>
        <source>New</source>
        <translation>새로 찍기</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="45"/>
        <source>Save</source>
        <translation>저장하기</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="46"/>
        <source>Copy</source>
        <translation>복사하기</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="47"/>
        <source>Options</source>
        <translation>옵션</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="48"/>
        <source>About</source>
        <translation>정보</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="49"/>
        <source>Quit</source>
        <translation>종료</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="358"/>
        <source>Screenshot </source>
        <translation>스크린숏 </translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="362"/>
        <source>Double click to open screenshot in external default image viewer</source>
        <translation>외부 기본 이미지 뷰어에서 스크린숏을 열려면 두 번 클릭</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="371"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="540"/>
        <source>Hide</source>
        <translation>숨김</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="547"/>
        <source>Show</source>
        <translation>표시하기</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="616"/>
        <source>%1 Files</source>
        <translation>%1 파일</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="638"/>
        <source>Save As...</source>
        <translation>다른 이름으로 저장하기...</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/core/regionselect.cpp" line="148"/>
        <source>Click and drag to draw a rectangle,
double click or press Enter
to take a screenshot,
or press Escape to cancel.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="245"/>
        <source>Click and drag to draw a rectangle,
right click to fit to edges,
double click or press Enter
to take a screenshot.</source>
        <translation>직사각형을 그리려면 클릭하고 드래그하고,
가장자리에 맞추려면 마우스 오른쪽 버튼을 클릭하고,
스크린숏을 찍으려면
더블클릭하거나 Enter를 눌러주세요.</translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="305"/>
        <source>%1 x %2 pixels </source>
        <translation>%1 x %2 픽셀 </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="35"/>
        <source>External edit</source>
        <translation>외부 편집하기</translation>
    </message>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="46"/>
        <source>Edit in...</source>
        <translation>다음에서 편집하기...</translation>
    </message>
</context>
<context>
    <name>aboutWidget</name>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="118"/>
        <source>About Qt</source>
        <translation>Qt 정보</translation>
    </message>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="144"/>
        <source>Close</source>
        <translation>닫기</translation>
    </message>
</context>
<context>
    <name>configwidget</name>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="26"/>
        <location filename="../src/core/ui/configwidget.ui" line="536"/>
        <source>Options</source>
        <translation>옵션</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="35"/>
        <source>Main</source>
        <translation>기본</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="40"/>
        <source>Advanced</source>
        <translation>고급</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="45"/>
        <source>System tray</source>
        <translation>시스템 트레이</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="50"/>
        <source>Shortcuts</source>
        <translation>단축키</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="74"/>
        <source>Default save directory</source>
        <translation>기본 저장 디렉터리</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="80"/>
        <source>Path to default selection dir for saving</source>
        <translation>저장을 위한 기본 선택 디렉터리 경로</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="93"/>
        <source>Browse filesystem</source>
        <translation>파일시스템 찾아보기</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="96"/>
        <source>Browse</source>
        <translation>찾아보기</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="106"/>
        <source>Default file</source>
        <translation>기본 파일</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="119"/>
        <source>Name:</source>
        <translation>이름:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="126"/>
        <source>Default filename</source>
        <translation>기본 파일이름</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="137"/>
        <source>Format</source>
        <translation>형식</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="150"/>
        <source>Default saving image format</source>
        <translation>기본 저장 이미지 형식</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="169"/>
        <source>Copy file name to the clipboard when saving</source>
        <translation>저장할 때 파일 이름을 클립보드에 복사하기</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="183"/>
        <source>Do not copy</source>
        <translation>복사 안함</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="188"/>
        <source>Copy file name only</source>
        <translation>파일 이름만 복사하기</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="193"/>
        <source>Copy full file path</source>
        <translation>전체 파일 경로 복사하기</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="203"/>
        <source>Image quality</source>
        <translation>이미지 품질</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="209"/>
        <source>Image quality (1 - small file, 100 - high quality)</source>
        <translation>이미지 품질(1 - 작은 파일, 100 - 고품질)</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="274"/>
        <source>Inserting current date time into saved filename</source>
        <translation>저장된 파일 이름에 현재 날짜 시간 삽입 중</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="277"/>
        <source>Insert current date and time in file name</source>
        <translation>파일 이름에 현재 날짜 및 시간 삽입</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="286"/>
        <source>Template: </source>
        <translation>템플릿: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="311"/>
        <source>Example: </source>
        <translation>예시: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="321"/>
        <source>Automatically saving screenshots in grabbing process</source>
        <translation>캡처 과정에서 스크린숏 자동으로 저장하기</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="324"/>
        <source>Autosave screenshot</source>
        <translation>스크린숏 자동저장</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="336"/>
        <source>Save first screenshot</source>
        <translation>첫 번째 스크린숏 저장하기</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="345"/>
        <source>Allow run multiplies copy of ScreenGrab</source>
        <translation>ScreenGrab의 연속 여러장 복사하기 허용</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="348"/>
        <source>Allow multiple instances of ScreenGrab</source>
        <translation>ScreenGrab의 다양한 인스턴스 허용</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="355"/>
        <source>Open in external viewer on double click</source>
        <translation>두 번 클릭하면 외부 뷰어에서 열기</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="358"/>
        <source>Enable external viewer</source>
        <translation>외부 뷰어 활성화</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="365"/>
        <source>If this is unchecked, the selected area
might become larger to fit to outer edges</source>
        <translation>선택하지 않으면 선택한 영역이 바깥쪽
가장자리에 맞게 커질 수 있습니다</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="369"/>
        <source>Fit to edges inside selected area by right clicking</source>
        <translation>마우스 오른쪽 버튼을 클릭하여 선택한 영역 내부의 가장자리에 맞추기</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="376"/>
        <source>With multiple screens</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="379"/>
        <source>Remember last selected screen in next session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="386"/>
        <source>Notify on saving and copying</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="395"/>
        <source>Duration:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="462"/>
        <source>Show ScreenGrab in the system tray</source>
        <translation>시스템 트레이에 ScreenGrab 표시하기</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="402"/>
        <source> sec</source>
        <translation> 초</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="469"/>
        <source>Minimize to tray on click close button</source>
        <translation>닫기 버튼 클릭 시 트레이로 최소화</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="472"/>
        <source>Minimize to tray when closing</source>
        <translation>닫을 때 트레이로 최소화</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="511"/>
        <source>Action</source>
        <translation>동작</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="516"/>
        <source>Shortcut</source>
        <translation>단축키</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="521"/>
        <source>New screen</source>
        <translation>새 화면</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="526"/>
        <source>Save screen</source>
        <translation>화면 저장하기</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="531"/>
        <source>Copy screen</source>
        <translation>화면 복사하기</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="541"/>
        <source>Quit</source>
        <translation>종료</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="551"/>
        <source>Selected shortcut:</source>
        <translation>선택한 단축키:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="558"/>
        <source>Not defined</source>
        <translation>정의되지 않음</translation>
    </message>
</context>
</TS>
